pub struct LootPool {
pub rolls: NumberProvider,
pub bonus_rolls: f32,
pub entries: &'static [LootEntry],
pub conditions: &'static [LootCondition],
pub functions: &'static [ConditionalLootFunction],
}Expand description
A pool of loot entries with roll counts.
Fields
rolls: NumberProviderbonus_rolls: f32entries: &'static [LootEntry]conditions: &'static [LootCondition]functions: &'static [ConditionalLootFunction]Implementations
Sourceimpl LootPool
impl LootPool
Sourcefn add_random_items<R: Rng>(
&self,
ctx: &mut LootContext<'_, R>,
result: &mut Vec<ItemStack>,
)
fn add_random_items<R: Rng>( &self, ctx: &mut LootContext<'_, R>, result: &mut Vec<ItemStack>, )
Add random items from this pool to the result.
Sourcefn add_random_item<R: Rng>(
&self,
ctx: &mut LootContext<'_, R>,
result: &mut Vec<ItemStack>,
)
fn add_random_item<R: Rng>( &self, ctx: &mut LootContext<'_, R>, result: &mut Vec<ItemStack>, )
Select and add a single random item from this pool.